Imported Upstream version 7.50.2
[platform/upstream/curl.git] / lib / ftp.h
index 7495e3e..2ed5b43 100644 (file)
--- a/lib/ftp.h
+++ b/lib/ftp.h
@@ -97,9 +97,9 @@ typedef enum {
                             file */
 } curl_ftpfile;
 
/* This FTP struct is used in the SessionHandle. All FTP data that is
    connection-oriented must be in FTP_conn to properly deal with the fact that
-   perhaps the SessionHandle is changed between the times the connection is
+   perhaps the Curl_easy is changed between the times the connection is
    used. */
 struct FTP {
   curl_off_t *bytecountp;
@@ -97,9 +97,9 @@ typedef enum {
 } curl_ftpfile;
 
-/* This FTP struct is used in the SessionHandle. All FTP data that is
+/* This FTP struct is used in the Curl_easy. All FTP data that is
    connection-oriented must be in FTP_conn to properly deal with the fact that